pub enum DocumentDiagnosticReportProgress {
DocumentDiagnosticReport(DocumentDiagnosticReport),
PartialResult(DocumentDiagnosticReportPartialResult),
}Expand description
The document diagnostic report used when reporting partial result.
When using partial results, the first literal sent needs to be a DocumentDiagnosticReport providing the diagnostics on the document followed by n DocumentDiagnosticReportPartialResult literals providing the diagnostics for related documents.
DocumentDiagnosticReport
DocumentDiagnosticReportPartialResult
DocumentDiagnosticReportPartialResult
...@since 3.18.1
Variants
DocumentDiagnosticReport(DocumentDiagnosticReport)
PartialResult(DocumentDiagnosticReportPartialResult)
DocumentDiagnosticReportPartialResult.