pub struct CallHierarchyIncomingCallsParams {
pub item: CallHierarchyItem,
pub work_done_token: Option<ProgressToken>,
pub partial_result_token: Option<ProgressToken>,
}Expand description
The parameter of a callHierarchy/incomingCalls request.
@since 3.16.0
Fields
item: CallHierarchyItemwork_done_token: Option<ProgressToken>An optional token that a server can use to report work done progress.
partial_result_token: Option<ProgressToken>An optional token that a server can use to report partial results (e.g. streaming) to the client.