pub struct DiagnosticClientCapabilities {
pub related_information: Option<bool>,
pub tag_support: Option<ClientDiagnosticsTagOptions>,
pub code_description_support: Option<bool>,
pub data_support: Option<bool>,
pub dynamic_registration: Option<bool>,
pub related_document_support: Option<bool>,
pub markup_message_support: Option<bool>,
}Expand description
Client capabilities specific to diagnostic pull requests.
@since 3.17.0
Fields
Whether the clients accepts diagnostics with related information.
tag_support: Option<ClientDiagnosticsTagOptions>Client supports the tag property to provide meta data about a diagnostic. Clients supporting tags have to handle unknown tags gracefully.
@since 3.15.0
code_description_support: Option<bool>Client supports a codeDescription property
@since 3.16.0
data_support: Option<bool>Whether code action supports the data property which is
preserved between a textDocument/publishDiagnostics and
textDocument/codeAction request.
@since 3.16.0
dynamic_registration: Option<bool>Whether implementation supports dynamic registration. If this is set to true
the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions)
return value for the corresponding server capability as well.
Whether the clients supports related documents for document diagnostic pulls.
markup_message_support: Option<bool>Whether the client supports MarkupContent in diagnostic messages.
@since 3.18.0