DocumentHighlightRegistrationOptions

Struct DocumentHighlightRegistrationOptions 

pub struct DocumentHighlightRegistrationOptions {
    pub document_selector: Option<DocumentSelector>,
}
Registration options for a {@link DocumentHighlightRequest}.

Fields

document_selector: Option<DocumentSelector>

A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.