pub struct ImplementationParams {
pub text_document: TextDocumentIdentifier,
pub position: Position,
pub work_done_token: Option<ProgressToken>,
pub partial_result_token: Option<ProgressToken>,
}Fields
text_document: TextDocumentIdentifierThe text document.
position: PositionThe position inside the text document.
work_done_token: Option<ProgressToken>An optional token that a server can use to report work done progress.
partial_result_token: Option<ProgressToken>An optional token that a server can use to report partial results (e.g. streaming) to the client.