pub struct RelatedUnchangedDocumentDiagnosticReport {
pub kind: String,
pub result_id: String,
pub related_documents: Option<HashMap<Uri, RelatedDocumentDiagnosticReport>>,
}Expand description
An unchanged diagnostic report with a set of related documents.
@since 3.17.0
Fields
kind: StringA document diagnostic report indicating
no changes to the last result. A server can
only return unchanged if result ids are
provided.
result_id: StringA result id which will be sent on the next diagnostic request for the same document.
Diagnostics of related documents. This information is useful in programming languages where code in a file A can generate diagnostics in a file B which A depends on. An example of such a language is C/C++ where marco definitions in a file a.cpp and result in errors in a header file b.hpp.
@since 3.17.0