pub struct WorkspaceUnchangedDocumentDiagnosticReport {
pub kind: String,
pub result_id: String,
pub uri: Uri,
pub version: Option<i32>,
}Expand description
An unchanged document diagnostic report for a workspace diagnostic result.
@since 3.17.0
Fields
kind: StringA document diagnostic report indicating
no changes to the last result. A server can
only return unchanged if result ids are
provided.
result_id: StringA result id which will be sent on the next diagnostic request for the same document.
uri: UriThe URI for which diagnostic information is reported.
version: Option<i32>The version number for which the diagnostics are reported.
If the document is not marked as open null can be provided.